# Jobcant

## Usage

```
jobcan --help
```

## Config

### Environment variables

- `JOBCAN_EMAIL`
- `JOBCAN_CLIENT_CODE`
- `JOBCAN_PASSWORD`

### Config file

```
jobcant config
```

## Build

```
python -m build
```
